@@ -14,7 +14,7 @@
 #include <set>
 #include <algorithm>
 
-#include <boost/regex.hpp>
+#include <regex.h>
 
 #include "../libstilton/pointaligned-s.hh"
 
@@ -380,7 +380,7 @@ void
 CNRun::CModel::
 unregister_listener( C_BaseUnit *u)
 {
-	auto U = find( lisn_unit_list.begin(), lisn_unit_list.end(), u);
+	const auto& U = find( lisn_unit_list.begin(), lisn_unit_list.end(), u);
 	if ( U != lisn_unit_list.end() )
 		lisn_unit_list.erase( U);
 }
@@ -667,7 +667,7 @@ add_synapse_species( TUnitType ytype, C_BaseNeuron *src, C_BaseNeuron *tgt,
 
       // consider cloning
 	if ( !(_status & CN_MDL_DONT_COALESCE) && allow_clone && src->_axonal_harbour.size() )
-		for ( auto &L : src->_axonal_harbour )
+		for ( auto& L : src->_axonal_harbour )
 			if ( L->_type == ytype &&
 			     L->is_not_altered() )
 				return L->clone_to_target( tgt, g);
@@ -922,16 +922,19 @@ int
 CNRun::CModel::
 process_listener_tags( const list<STagGroupListener> &Listeners)
 {
-	for ( auto P = Listeners.begin(); P != Listeners.end(); P++ ) {
-		boost::regex pattern( P->pattern.c_str());
-		boost::cmatch found;
+	regex_t RE;
+	for ( auto& P : Listeners ) {
+		if (0 != regcomp( &RE, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB)) {
+			fprintf( stderr, "Invalid regexp in process_listener_tags: \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
 		for_all_units (U) {
-			if ( boost::regex_match( (*U)->_label, found, pattern) ) {
-				if ( P->enable ) {
-					(*U) -> start_listening( P->bits);
+			if ( regexec( &RE, (*U)->_label, 0, 0, 0) == 0 ) {
+				if ( P.enable ) {
+					(*U) -> start_listening( P.bits);
 					if ( verbosely > 3 )
 						printf( " (unit \"%s\" listening%s)\n",
-							(*U)->_label, P->bits & CN_ULISTENING_1VARONLY ? ", to one var only" :"");
+							(*U)->_label, P.bits & CN_ULISTENING_1VARONLY ? ", to one var only" :"");
 				} else {
 					(*U) -> stop_listening();
 					if ( verbosely > 3 )
@@ -949,14 +952,17 @@ int
 CNRun::CModel::
 process_spikelogger_tags( const list<STagGroupSpikelogger> &Spikeloggers)
 {
-	for ( auto P = Spikeloggers.begin(); P != Spikeloggers.end(); P++ ) {
-		boost::regex pattern( P->pattern.c_str());
-		boost::cmatch found;
+	regex_t RE;
+	for ( auto& P : Spikeloggers ) {
+		if (0 != regcomp( &RE, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB)) {
+			fprintf( stderr, "Invalid regexp in process_spikelogger_tags: \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
 		for_all_standalone_neurons (N) {
-			if ( boost::regex_match( (*N)->_label, found, pattern) ) {
-				if ( P->enable ) {
-					bool log_sdf = !(P->period == 0. || P->sigma == 0.);
-					if ( ( log_sdf && !(*N)->enable_spikelogging_service( P->period, P->sigma, P->from))
+			if ( regexec( &RE, (*N)->_label, 0, 0, 0) == 0 ) {
+				if ( P.enable ) {
+					bool log_sdf = !(P.period == 0. || P.sigma == 0.);
+					if ( ( log_sdf && !(*N)->enable_spikelogging_service( P.period, P.sigma, P.from))
 					     ||
 					     (!log_sdf && !(*N)->enable_spikelogging_service()) ) {
 						fprintf( stderr, "Cannot have \"%s\" log spikes because it is not a conductance-based neuron (of type %s)\n",
@@ -968,14 +974,14 @@ process_spikelogger_tags( const list<STagGroupSpikelogger> &Spikeloggers)
 
 				if ( verbosely > 3 )
 					printf( " (%sabling spike logging for standalone neuron \"%s\")\n",
-						P->enable ? "en" : "dis", (*N)->_label);
+						P.enable ? "en" : "dis", (*N)->_label);
 			}
 		}
 		for_all_hosted_neurons (N) {
-			if ( boost::regex_match( (*N)->_label, found, pattern) ) {
-				if ( P->enable ) {
-					bool log_sdf = !(P->period == 0. || P->sigma == 0.);
-					if ( ( log_sdf && !(*N)->enable_spikelogging_service( P->period, P->sigma, P->from))
+			if ( regexec( &RE, (*N)->_label, 0, 0, 0) == 0 ) {
+				if ( P.enable ) {
+					bool log_sdf = !(P.period == 0. || P.sigma == 0.);
+					if ( ( log_sdf && !(*N)->enable_spikelogging_service( P.period, P.sigma, P.from))
 					     ||
 					     (!log_sdf && !(*N)->enable_spikelogging_service()) ) {
 						fprintf( stderr, "Cannot have \"%s\" log spikes because it is not a conductance-based neuron (of type %s)\n",
@@ -987,7 +993,7 @@ process_spikelogger_tags( const list<STagGroupSpikelogger> &Spikeloggers)
 
 				if ( verbosely > 3 )
 					printf( " (%sabling spike logging for hosted neuron \"%s\")\n",
-						P->enable ? "en" : "dis", (*N)->_label);
+						P.enable ? "en" : "dis", (*N)->_label);
 			}
 		}
 	}
@@ -1001,11 +1007,14 @@ CNRun::CModel::
 process_putout_tags( const list<STagGroup> &ToRemove)
 {
       // execute some
-	for ( auto P = ToRemove.begin(); P != ToRemove.end(); P++ ) {
-		boost::regex pattern( P->pattern.c_str());
-		boost::cmatch found;
+	regex_t RE;
+	for ( auto& P : ToRemove ) {
+		if (0 != regcomp( &RE, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB)) {
+			fprintf( stderr, "Invalid regexp in process_putout_tags: \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
 		for_all_units (U) {
-			if ( boost::regex_match( (*U)->_label, found, pattern) ) {
+			if ( regexec( &RE, (*U)->_label, 0, 0, 0) == 0 ) {
 				if ( verbosely > 2 )
 					printf( " (put out unit \"%s\")\n",
 						(*U)->_label);
@@ -1029,24 +1038,27 @@ CNRun::CModel::
 process_decimate_tags( const list<STagGroupDecimate> &ToDecimate)
 {
       // decimate others
-	for ( auto P = ToDecimate.begin(); P != ToDecimate.end(); P++ ) {
-		boost::regex pattern( P->pattern.c_str());
-		boost::cmatch found;
+	regex_t RE;
+	for ( auto& P : ToDecimate ) {
+		if (0 != regcomp( &RE, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB)) {
+			fprintf( stderr, "Invalid regexp in process_decimate_tags: \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
 
 	      // collect group
 		vector<C_BaseUnit*> dcmgroup;
 		for_all_units (U)
-			if ( boost::regex_match( (*U)->_label, found, pattern) )
+			if ( regexec( &RE, (*U)->_label, 0, 0, 0) == 0 )
 				dcmgroup.push_back( *U);
 		random_shuffle( dcmgroup.begin(), dcmgroup.end());
 
 	      // execute
-		size_t	to_execute = rint( dcmgroup.size() * P->fraction), n = to_execute;
+		size_t	to_execute = rint( dcmgroup.size() * P.fraction), n = to_execute;
 		while ( n-- )
 			delete dcmgroup[n];
 
 		if ( verbosely > 3 )
-			printf( " (decimated %4.1f%% (%zu units) of %s)\n", P->fraction*100, to_execute, P->pattern.c_str());
+			printf( " (decimated %4.1f%% (%zu units) of %s)\n", P.fraction*100, to_execute, P.pattern.c_str());
 
 	}
 
@@ -1064,37 +1076,40 @@ int
 CNRun::CModel::
 process_paramset_static_tags( const list<STagGroupNeuronParmSet> &tags)
 {
-	for ( auto P = tags.begin(); P != tags.end(); P++ ) {
-		boost::regex pattern( P->pattern.c_str());
-		boost::cmatch found;
+	regex_t RE;
+	for ( auto& P : tags ) {
+		if (0 != regcomp( &RE, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB)) {
+			fprintf( stderr, "Invalid regexp in process_paramset_static_tags: \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
 
 		vector<string> current_tag_assigned_labels;
 
 		for_all_neurons (U) {
-			if ( !boost::regex_match( (*U)->label(), found, pattern) )
+			if ( regexec( &RE, (*U)->_label, 0, 0, 0) == 0 )
 				continue;
 		      // because a named parameter can map to a different param_id in different units, rather
 		      // do lookup every time
 
 			int p_d = -1;
 			C_BaseUnit::TSinkType kind = (C_BaseUnit::TSinkType)-1;
-			if ( (p_d = (*U)->param_idx_by_sym( P->parm.c_str())) > -1 )
+			if ( (p_d = (*U)->param_idx_by_sym( P.parm.c_str())) > -1 )
 				kind = C_BaseUnit::SINK_PARAM;
-			else if ( (p_d = (*U)->var_idx_by_sym( P->parm.c_str())) > -1 )
+			else if ( (p_d = (*U)->var_idx_by_sym( P.parm.c_str())) > -1 )
 				kind = C_BaseUnit::SINK_VAR;
 			if ( p_d == -1 ) {
 				fprintf( stderr, "%s \"%s\" (type \"%s\") has no parameter or variable named \"%s\"\n",
-					 (*U)->class_name(), (*U)->label(), (*U)->species(), P->parm.c_str());
+					 (*U)->class_name(), (*U)->label(), (*U)->species(), P.parm.c_str());
 				continue;
 			}
 
 			switch ( kind ) {
 			case C_BaseUnit::SINK_PARAM:
-				(*U)->param_value(p_d) = P->enable ? P->value : __CNUDT[(*U)->type()].stock_param_values[p_d];
+				(*U)->param_value(p_d) = P.enable ? P.value : __CNUDT[(*U)->type()].stock_param_values[p_d];
 				(*U)->param_changed_hook();
 			    break;
 			case C_BaseUnit::SINK_VAR:
-				(*U)->  var_value(p_d) = P->value;
+				(*U)->  var_value(p_d) = P.value;
 			    break;
 			}
 
@@ -1102,7 +1117,7 @@ process_paramset_static_tags( const list<STagGroupNeuronParmSet> &tags)
 		}
 
 		if ( current_tag_assigned_labels.empty() ) {
-			fprintf( stderr, "No neuron labelled matching \"%s\"\n", P->pattern.c_str());
+			fprintf( stderr, "No neuron labelled matching \"%s\"\n", P.pattern.c_str());
 			return -2;
 		}
 
@@ -1111,7 +1126,7 @@ process_paramset_static_tags( const list<STagGroupNeuronParmSet> &tags)
 			for ( auto S = current_tag_assigned_labels.begin(); S != current_tag_assigned_labels.end(); S++ )
 				printf( "%s%s",
 					(S == current_tag_assigned_labels.begin()) ? "" : ", ", S->c_str());
-			printf( " {%s} = %g\n", P->parm.c_str(), P->value);
+			printf( " {%s} = %g\n", P.parm.c_str(), P.value);
 		}
 	}
 	return 0;
@@ -1125,45 +1140,50 @@ int
 CNRun::CModel::
 process_paramset_static_tags( const list<STagGroupSynapseParmSet> &tags)
 {
-	for ( list<STagGroupSynapseParmSet>::const_iterator P = tags.begin(); P != tags.end(); P++ ) {
-		boost::regex
-			pattern_src (P->pattern.c_str()),  // P->pattern acting as src
-			pattern_tgt (P->target.c_str());
-		boost::cmatch found;
+	for ( auto& P : tags ) {
+		regex_t REsrc, REtgt;
+		if (0 != regcomp( &REsrc, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB) ) {  // P->pattern acting as src
+			fprintf( stderr, "Invalid regexp in process_paramset_static_tags (src): \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
+		if (0 != regcomp( &REtgt, P.target.c_str(), REG_EXTENDED | REG_NOSUB) ) {
+			fprintf( stderr, "Invalid regexp in process_paramset_static_tags (tgt): \"%s\"\n", P.target.c_str());
+			return -1;
+		}
 
 		vector<string> current_tag_assigned_labels;
 
-		bool do_gsyn = (P->parm == "gsyn");
+		bool do_gsyn = (P.parm == "gsyn");
 
 		if ( verbosely > 5 )
-			printf( "== setting %s -> %s {%s} = %g...\n", P->pattern.c_str(), P->target.c_str(), P->parm.c_str(), P->value);
+			printf( "== setting %s -> %s {%s} = %g...\n", P.pattern.c_str(), P.target.c_str(), P.parm.c_str(), P.value);
 
 		for_all_neurons (Us) {
-			if ( !boost::regex_match( (*Us)->label(), found, pattern_src) )
+			if ( regexec( &REsrc, (*Us)->label(), 0, 0, 0) == 0 )
 				continue;
 
 			for_all_neurons (Ut) {
-				if ( !boost::regex_match( (*Ut)->label(), found, pattern_tgt) /* || Us == Ut */ )
+                if ( regexec( &REtgt, (*Ut)->label(), 0, 0, 0) == 0 ) /* || Us == Ut */
 					continue;
 				C_BaseSynapse *y = static_cast<C_BaseNeuron*>(*Us) -> connects_via( *static_cast<C_BaseNeuron*>(*Ut));
 				if ( !y )
 					continue;
 
 				if ( do_gsyn ) {
-					y->set_g_on_target( *static_cast<C_BaseNeuron*>(*Ut), P->value);
+					y->set_g_on_target( *static_cast<C_BaseNeuron*>(*Ut), P.value);
 					current_tag_assigned_labels.push_back( y->label());
 					continue;
 				}
 
 				int p_d = -1;
 				C_BaseUnit::TSinkType kind = (C_BaseUnit::TSinkType)-1;
-				if ( (p_d = y->param_idx_by_sym( P->parm.c_str())) > -1 )
+				if ( (p_d = y->param_idx_by_sym( P.parm.c_str())) > -1 )
 					kind = C_BaseUnit::SINK_PARAM;
-				else if ( (p_d = y->var_idx_by_sym( P->parm.c_str())) > -1 )
+				else if ( (p_d = y->var_idx_by_sym( P.parm.c_str())) > -1 )
 					kind = C_BaseUnit::SINK_VAR;
 				if ( p_d == -1 ) {
 					fprintf( stderr, "%s \"%s\" (type \"%s\") has no parameter or variable named \"%s\"\n",
-						 y->class_name(), y->label(), y->species(), P->parm.c_str());
+						 y->class_name(), y->label(), y->species(), P.parm.c_str());
 					continue;
 				}
 
@@ -1172,11 +1192,11 @@ process_paramset_static_tags( const list<STagGroupSynapseParmSet> &tags)
 					if ( y->_targets.size() > 1 ) {
 						y = y->make_clone_independent( static_cast<C_BaseNeuron*>(*Ut));  // lest brethren synapses to other targets be clobbered
 					}
-					y->param_value(p_d) = P->enable ? P->value : __CNUDT[y->type()].stock_param_values[p_d];
+					y->param_value(p_d) = P.enable ? P.value : __CNUDT[y->type()].stock_param_values[p_d];
 					y->param_changed_hook();
 				    break;
 				case C_BaseUnit::SINK_VAR:
-					y->  var_value(p_d) = P->value;
+					y->  var_value(p_d) = P.value;
 				    break;
 				}
 
@@ -1184,7 +1204,7 @@ process_paramset_static_tags( const list<STagGroupSynapseParmSet> &tags)
 			}
 		}
 		if ( current_tag_assigned_labels.empty() ) {
-			fprintf( stderr, "No synapse connecting any of \"%s\" to \"%s\"\n", P->pattern.c_str(), P->target.c_str());
+			fprintf( stderr, "No synapse connecting any of \"%s\" to \"%s\"\n", P.pattern.c_str(), P.target.c_str());
 			return -2;
 		}
 
@@ -1193,7 +1213,7 @@ process_paramset_static_tags( const list<STagGroupSynapseParmSet> &tags)
 			for ( auto S = current_tag_assigned_labels.begin(); S != current_tag_assigned_labels.end(); S++ )
 				printf( "%s%s",
 					(S == current_tag_assigned_labels.begin()) ? "" : ", ", S->c_str());
-			printf( " {%s} = %g\n", P->parm.c_str(), P->value);
+			printf( " {%s} = %g\n", P.parm.c_str(), P.value);
 		}
 	}
 
@@ -1243,36 +1263,39 @@ int
 CNRun::CModel::
 process_paramset_source_tags( const list<STagGroupSource> &tags)
 {
-	for ( list<STagGroupSource>::const_iterator P = tags.begin(); P != tags.end(); P++ ) {
-		boost::regex pattern( P->pattern.c_str());
-		boost::cmatch found;
+	regex_t RE;
+	for ( auto& P : tags ) {
+		if (0 != regcomp( &RE, P.pattern.c_str(), REG_EXTENDED | REG_NOSUB)) {
+			fprintf( stderr, "Invalid regexp in process_paramset_source_tags: \"%s\"\n", P.pattern.c_str());
+			return -1;
+		}
 
 		for_all_units (U) {
-			if ( !boost::regex_match( (*U)->label(), found, pattern) )
+			if ( regexec( &RE, (*U)->label(), 0, 0, 0) == 0 )
 				continue;
 
 			int p_d = -1;
 			C_BaseUnit::TSinkType kind = (C_BaseUnit::TSinkType)-1;
-			if ( (p_d = (*U)->param_idx_by_sym( P->parm.c_str())) > -1 )
+			if ( (p_d = (*U)->param_idx_by_sym( P.parm.c_str())) > -1 )
 				kind = C_BaseUnit::SINK_PARAM;
-			else if ( (p_d = (*U)->var_idx_by_sym( P->parm.c_str())) > -1 )
+			else if ( (p_d = (*U)->var_idx_by_sym( P.parm.c_str())) > -1 )
 				kind = C_BaseUnit::SINK_VAR;
 			if ( p_d == -1 ) {
 				fprintf( stderr, "%s \"%s\" (type \"%s\") has no parameter or variable named \"%s\"\n",
-					 (*U)->class_name(), (*U)->label(), (*U)->species(), P->parm.c_str());
+					 (*U)->class_name(), (*U)->label(), (*U)->species(), P.parm.c_str());
 				continue;
 			}
 
-			if ( P->enable ) {
-				(*U) -> attach_source( P->source, kind, p_d);
+			if ( P.enable ) {
+				(*U) -> attach_source( P.source, kind, p_d);
 				if ( verbosely > 3 )
 					printf( "Connected source \"%s\" to \"%s\"{%s}\n",
-						P->source->name.c_str(), (*U)->label(), P->parm.c_str());
+						P.source->name.c_str(), (*U)->label(), P.parm.c_str());
 			} else {
-				(*U) -> detach_source( P->source, kind, p_d);
+				(*U) -> detach_source( P.source, kind, p_d);
 				if ( verbosely > 3 )
 					printf( "Disconnected source \"%s\" from \"%s\"{%s}\n",
-						P->source->name.c_str(), (*U)->label(), P->parm.c_str());
+						P.source->name.c_str(), (*U)->label(), P.parm.c_str());
 			}
 		}
 	}
@@ -1396,6 +1419,3 @@ dump_units( FILE *strm)
 	fprintf( strm, "\n");
 }
 
-
-
-// eof
