@@ -10,8 +10,10 @@
 
 
 #include <sys/stat.h>
-
 #include <stdio.h>
+#include <unistd.h>
+#include <cassert>
+#include <regex.h>
 #include <list>
 #include <initializer_list>
 
@@ -29,8 +31,6 @@
 #  include <history.h>
 #  endif
 
-#include "boost/regex.hpp"
-
 #include "runner.hh"
 #include "libstilton/exprparser.hh"
 #include "libcn/integrate-rk65.hh"
@@ -86,7 +86,7 @@ list<SVariable> *current_shell_variables;
 
 
 
-inline namespace {
+namespace {
 
 void
 LOG( const char *fname, int lineno, int vrb, const char* fmt, ...)
@@ -280,13 +280,16 @@ do_single_cmd( const char* raw,
 		CHECK_MODEL;
 		if ( !operand )
 			operand = const_cast<char*>(".*");
-		boost::regex pattern( operand);
-		boost::cmatch found;
+		regex_t RE;
+		if ( 0 != regcomp( &RE, operand, REG_EXTENDED | REG_NOSUB) ) {
+			LOG( fname, lineno, -1, "Invalid regexp for `reset_state_units' arg");
+			return CN_INTERP_PARSEERROR;
+		}
 		size_t cnt = 0;
 		for_model_units (Model,U)
-			if ( boost::regex_match( (*U)->label(), found, pattern) ) {
+			if ( regexec( &RE, (*U)->label(), 0, 0, 0) == 0 ) {
 				(*U) -> reset_state();
-				cnt++;
+				++cnt;
 			}
 		if ( cnt )
 			Log->msg( 0, nullptr, "Reset %zd unit(s)", cnt);
@@ -686,11 +689,14 @@ do_single_cmd( const char* raw,
 		if ( !operand )
 			operand = const_cast<char*>(".*");
 
-		boost::regex pattern( operand);
-		boost::cmatch found;
+		regex_t RE;
+		if ( 0 != regcomp( &RE, operand, REG_EXTENDED | REG_NOSUB) ) {
+			LOG( fname, lineno, -1, "Invalid regexp for `show_units' arg");
+			return CN_INTERP_PARSEERROR;
+		}
 		size_t cnt = 0;
 		for_model_units (Model,U)
-			if ( boost::regex_match( (*U)->label(), found, pattern) ) {
+			if ( regexec( &RE, (*U)->label(), 0, 0, 0) == 0 ) {
 				(*U) -> dump( true);
 				cnt++;
 			}
@@ -724,18 +730,21 @@ do_single_cmd( const char* raw,
 	} else if ( strcmp( cmd, cnrun_cmd[CNCMD_show_vars]) == 0 ) {
 		if ( !operand )
 			operand = const_cast<char*>(".*");
-		boost::regex pattern( operand);
-		boost::cmatch found;
+		regex_t RE;
+		if ( 0 != regcomp( &RE, operand, REG_EXTENDED | REG_NOSUB) ) {
+			LOG( fname, lineno, -1, "Invalid regexp for `show_vars' arg");
+			return CN_INTERP_PARSEERROR;
+		}
 		size_t	cnt = 0;
 		size_t	longest_id = 0;
-		for ( list<SVariable>::iterator V = varlist.begin(); V != varlist.end(); V++ )
-			if ( boost::regex_match( V->name, found, pattern) )
-				if ( longest_id < strlen( V->name) )
-					longest_id = strlen( V->name);
-		for ( list<SVariable>::iterator V = varlist.begin(); V != varlist.end(); V++ )
-			if ( boost::regex_match( V->name, found, pattern) ) {
-				Log->msg( 0, nullptr, "  %*s = %g", longest_id, V->name, V->value);
-				cnt++;
+		for ( auto& V : varlist )
+			if ( regexec( &RE, V.name, 0, 0, 0) == 0 )
+				if ( longest_id < strlen( V.name) )
+					longest_id = strlen( V.name);
+		for ( auto& V : varlist )
+			if ( regexec( &RE, V.name, 0, 0, 0) == 0 ) {
+				Log->msg( 0, nullptr, "  %*s = %g", longest_id, V.name, V.value);
+				++cnt;
 			}
 		if ( cnt > 1 )
 			Log->msg_( 0, nullptr, "---------- %u variables\n", cnt);
@@ -745,10 +754,13 @@ do_single_cmd( const char* raw,
 		if ( !operand )
 			varlist.clear();
 		else {
-			boost::regex pattern( operand);
-			boost::cmatch found;
+			regex_t RE;
+			if ( 0 != regcomp( &RE, operand, REG_EXTENDED | REG_NOSUB) ) {
+				LOG( fname, lineno, -1, "Invalid regexp for `clear_vars' arg");
+				return CN_INTERP_PARSEERROR;
+			}
 			for ( list<SVariable>::iterator V = varlist.begin(); V != varlist.end(); V++ )
-				if ( boost::regex_match( V->name, found, pattern) ) {
+				if ( regexec( &RE, V->name, 0, 0, 0) == 0 ) {
 					varlist.erase( V);
 					break;
 				}
@@ -911,5 +923,3 @@ interpreter_run( const char *script_fname, int level, int howstrict,
 	return retval;
 }
 
-
-// EOF
